##  Microsoft Dynamics
The following model shows an implementation of the enterprise suite of Microsoft Dynamics.
![2018](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274619a17a44101498a7a94770b56cf3_LowRes.png)
